@@ -28,20 +28,21 @@ import java.lang.annotation.Target;
  * @since Common Annotations 1.0
  */
 @Documented
-@Target({ElementType.ANNOTATION_TYPE, ElementType.CONSTRUCTOR,
-    ElementType.FIELD, ElementType.LOCAL_VARIABLE, ElementType.METHOD,
-    ElementType.PACKAGE, ElementType.PARAMETER, ElementType.TYPE})
+@Target({ ElementType.ANNOTATION_TYPE, ElementType.CONSTRUCTOR, ElementType.FIELD, ElementType.LOCAL_VARIABLE,
+        ElementType.METHOD, ElementType.PACKAGE, ElementType.PARAMETER, ElementType.TYPE })
 @Retention(RetentionPolicy.SOURCE)
 public @interface Generated {
     /**
-     * @return The name of the code generator. It is recommended that the fully
-     *         qualified name of the code generator is used.
+     * @return The name of the code generator. It is recommended that the fully qualified name of the code generator is
+     *             used.
      */
     String[] value();
+
     /**
      * @return The date the code was generated
      */
     String date() default "";
+
     /**
      * @return Additional comments (if any) related to the code generation
      */
