@@ -406,6 +406,11 @@ public class Response implements HttpServletResponse {
     }
 
 
+    public void resetError() {
+        getCoyoteResponse().resetError();
+    }
+
+
     /**
      * Perform whatever actions are required to flush and close the output stream or writer, in a single operation.
      *
@@ -425,10 +430,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * @return the content type that was set or calculated for this response, or <code>null</code> if no content type
-     *             was set.
-     */
     @Override
     public String getContentType() {
         return getCoyoteResponse().getContentType();
@@ -461,29 +462,18 @@ public class Response implements HttpServletResponse {
     // ------------------------------------------------ ServletResponse Methods
 
 
-    /**
-     * Flush the buffer and commit this response.
-     *
-     * @exception IOException if an input/output error occurs
-     */
     @Override
     public void flushBuffer() throws IOException {
         outputBuffer.flush();
     }
 
 
-    /**
-     * @return the actual buffer size used for this Response.
-     */
     @Override
     public int getBufferSize() {
         return outputBuffer.getBufferSize();
     }
 
 
-    /**
-     * @return the character encoding used for this Response.
-     */
     @Override
     public String getCharacterEncoding() {
         String charset = getCoyoteResponse().getCharacterEncoding();
@@ -505,12 +495,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * @return the servlet output stream associated with this Response.
-     *
-     * @exception IllegalStateException if <code>getWriter</code> has already been called for this response
-     * @exception IOException           if an input/output error occurs
-     */
     @Override
     public ServletOutputStream getOutputStream() throws IOException {
 
@@ -527,21 +511,12 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * @return the Locale assigned to this response.
-     */
     @Override
     public Locale getLocale() {
         return getCoyoteResponse().getLocale();
     }
 
 
-    /**
-     * @return the writer associated with this Response.
-     *
-     * @exception IllegalStateException if <code>getOutputStream</code> has already been called for this response
-     * @exception IOException           if an input/output error occurs
-     */
     @Override
     public PrintWriter getWriter() throws IOException {
 
@@ -570,22 +545,12 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Has the output of this response already been committed?
-     *
-     * @return <code>true</code> if the response has been committed
-     */
     @Override
     public boolean isCommitted() {
         return getCoyoteResponse().isCommitted();
     }
 
 
-    /**
-     * Clear any content written to the buffer.
-     *
-     * @exception IllegalStateException if this response has already been committed
-     */
     @Override
     public void reset() {
         // Ignore any call from an included servlet
@@ -601,11 +566,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Reset the data buffer but not any status or header information.
-     *
-     * @exception IllegalStateException if the response has already been committed
-     */
     @Override
     public void resetBuffer() {
         resetBuffer(false);
@@ -638,13 +598,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the buffer size to be used for this Response.
-     *
-     * @param size The new buffer size
-     *
-     * @exception IllegalStateException if this method is called after output has been committed for this response
-     */
     @Override
     public void setBufferSize(int size) {
 
@@ -657,11 +610,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the content length (in bytes) for this Response.
-     *
-     * @param length The new content length
-     */
     @Override
     public void setContentLength(int length) {
 
@@ -684,11 +632,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the content type for this Response.
-     *
-     * @param type The new content type
-     */
     @Override
     public void setContentType(String type) {
 
@@ -745,12 +688,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Overrides the name of the character encoding used in the body of the request. This method must be called prior to
-     * reading request parameters or reading input using getReader().
-     *
-     * @param encoding String containing the name of the character encoding.
-     */
     @Override
     public void setCharacterEncoding(String encoding) {
 
@@ -783,11 +720,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the Locale that is appropriate for this response, including setting the appropriate character encoding.
-     *
-     * @param locale The new locale
-     */
     @Override
     public void setLocale(Locale locale) {
 
@@ -949,12 +881,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Add the specified date header to the specified value.
-     *
-     * @param name  Name of the header to set
-     * @param value Date value to be set
-     */
     @Override
     public void addDateHeader(String name, long value) {
 
@@ -975,12 +901,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Add the specified header to the specified value.
-     *
-     * @param name  Name of the header to set
-     * @param value Value to be set
-     */
     @Override
     public void addHeader(String name, String value) {
         addHeader(name, value, null);
@@ -1029,12 +949,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Add the specified integer header to the specified value.
-     *
-     * @param name  Name of the header to set
-     * @param value Integer value to be set
-     */
     @Override
     public void addIntHeader(String name, int value) {
 
@@ -1056,13 +970,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Has the specified header been set already in this response?
-     *
-     * @param name Name of the header to check
-     *
-     * @return <code>true</code> if the header has been set
-     */
     @Override
     public boolean containsHeader(String name) {
         // Need special handling for Content-Type and Content-Length due to
@@ -1095,13 +1002,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Encode the session identifier associated with this response into the specified redirect URL, if necessary.
-     *
-     * @param url URL to be encoded
-     *
-     * @return <code>true</code> if the URL was encoded
-     */
     @Override
     public String encodeRedirectURL(String url) {
         if (isEncodeable(toAbsolute(url))) {
@@ -1112,13 +1012,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Encode the session identifier associated with this response into the specified URL, if necessary.
-     *
-     * @param url URL to be encoded
-     *
-     * @return <code>true</code> if the URL was encoded
-     */
     @Override
     public String encodeURL(String url) {
 
@@ -1168,29 +1061,12 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Send an error response with the specified status and a default message.
-     *
-     * @param status HTTP status code to send
-     *
-     * @exception IllegalStateException if this response has already been committed
-     * @exception IOException           if an input/output error occurs
-     */
     @Override
     public void sendError(int status) throws IOException {
         sendError(status, null);
     }
 
 
-    /**
-     * Send an error response with the specified status and message.
-     *
-     * @param status  HTTP status code to send
-     * @param message Corresponding message to send
-     *
-     * @exception IllegalStateException if this response has already been committed
-     * @exception IOException           if an input/output error occurs
-     */
     @Override
     public void sendError(int status, String message) throws IOException {
 
@@ -1275,12 +1151,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the specified date header to the specified value.
-     *
-     * @param name  Name of the header to set
-     * @param value Date value to be set
-     */
     @Override
     public void setDateHeader(String name, long value) {
 
@@ -1301,12 +1171,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the specified header to the specified value.
-     *
-     * @param name  Name of the header to set
-     * @param value Value to be set
-     */
     @Override
     public void setHeader(String name, String value) {
 
@@ -1334,12 +1198,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the specified integer header to the specified value.
-     *
-     * @param name  Name of the header to set
-     * @param value Integer value to be set
-     */
     @Override
     public void setIntHeader(String name, int value) {
 
@@ -1361,11 +1219,6 @@ public class Response implements HttpServletResponse {
     }
 
 
-    /**
-     * Set the HTTP status to be returned with this response.
-     *
-     * @param status The new HTTP status
-     */
     @Override
     public void setStatus(int status) {
 
