@@ -92,6 +92,9 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
         }
     }
 
+    private static final int shortestSpecialNameLength =
+            specialsMap.keySet().stream().mapToInt(s -> s.length()).min().getAsInt();
+
 
     private static final int SPECIALS_FIRST_FORWARD_INDEX = 6;
 
@@ -738,6 +741,10 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @param name Attribute name to be tested
      */
     protected boolean isSpecial(String name) {
+        // Performance - see BZ 68089
+        if (name.length() < shortestSpecialNameLength) {
+            return false;
+        }
         return specialsMap.containsKey(name);
     }
 
@@ -748,6 +755,10 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @return the special attribute pos, or -1 if it is not a special attribute
      */
     protected int getSpecial(String name) {
+        // Performance - see BZ 68089
+        if (name.length() < shortestSpecialNameLength) {
+            return -1;
+        }
         Integer index = specialsMap.get(name);
         if (index == null) {
             return -1;
@@ -762,6 +773,10 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      * @return true if the attribute was a special attribute, false otherwise
      */
     protected boolean setSpecial(String name, Object value) {
+        // Performance - see BZ 68089
+        if (name.length() < shortestSpecialNameLength) {
+            return false;
+        }
         Integer index = specialsMap.get(name);
         if (index == null) {
             return false;
