@@ -28,7 +28,6 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.StringTokenizer;
-import java.util.regex.Pattern;
 
 import jakarta.servlet.FilterChain;
 import jakarta.servlet.FilterConfig;
@@ -44,6 +43,7 @@ import jakarta.servlet.http.MappingMatch;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
+import org.apache.tomcat.util.buf.StringUtils;
 
 /**
  * <p>
@@ -446,8 +446,13 @@ public class ExpiresFilter extends FilterBase {
      * Duration unit
      */
     protected enum DurationUnit {
-        DAY(Calendar.DAY_OF_YEAR), HOUR(Calendar.HOUR), MINUTE(Calendar.MINUTE), MONTH(Calendar.MONTH),
-        SECOND(Calendar.SECOND), WEEK(Calendar.WEEK_OF_YEAR), YEAR(Calendar.YEAR);
+        DAY(Calendar.DAY_OF_YEAR),
+        HOUR(Calendar.HOUR),
+        MINUTE(Calendar.MINUTE),
+        MONTH(Calendar.MONTH),
+        SECOND(Calendar.SECOND),
+        WEEK(Calendar.WEEK_OF_YEAR),
+        YEAR(Calendar.YEAR);
 
         private final int calendarField;
 
@@ -506,7 +511,8 @@ public class ExpiresFilter extends FilterBase {
      * {@link StartingPoint#LAST_MODIFICATION_TIME}).
      */
     protected enum StartingPoint {
-        ACCESS_TIME, LAST_MODIFICATION_TIME
+        ACCESS_TIME,
+        LAST_MODIFICATION_TIME
     }
 
     /**
@@ -1004,11 +1010,6 @@ public class ExpiresFilter extends FilterBase {
 
     }
 
-    /**
-     * {@link Pattern} for a comma delimited string that support whitespace characters
-     */
-    private static final Pattern commaSeparatedValuesPattern = Pattern.compile("\\s*,\\s*");
-
     private static final String HEADER_CACHE_CONTROL = "Cache-Control";
 
     private static final String HEADER_EXPIRES = "Expires";
@@ -1033,7 +1034,7 @@ public class ExpiresFilter extends FilterBase {
      * @return never {@code null} array
      */
     protected static int[] commaDelimitedListToIntArray(String commaDelimitedInts) {
-        String[] intsAsStrings = commaDelimitedListToStringArray(commaDelimitedInts);
+        String[] intsAsStrings = StringUtils.splitCommaSeparated(commaDelimitedInts);
         int[] ints = new int[intsAsStrings.length];
         for (int i = 0; i < intsAsStrings.length; i++) {
             String intAsString = intsAsStrings[i];
@@ -1053,10 +1054,12 @@ public class ExpiresFilter extends FilterBase {
      * @param commaDelimitedStrings the string to be split
      *
      * @return array of patterns (non {@code null})
+     *
+     * @deprecated Unused. Will be removed in Tomcat 11.
      */
+    @Deprecated
     protected static String[] commaDelimitedListToStringArray(String commaDelimitedStrings) {
-        return (commaDelimitedStrings == null || commaDelimitedStrings.length() == 0) ? new String[0]
-                : commaSeparatedValuesPattern.split(commaDelimitedStrings);
+        return StringUtils.splitCommaSeparated(commaDelimitedStrings);
     }
 
     /**
@@ -1167,7 +1170,7 @@ public class ExpiresFilter extends FilterBase {
     /**
      * Expires configuration by content type. Visible for test.
      */
-    private Map<String, ExpiresConfiguration> expiresConfigurationByContentType = new LinkedHashMap<>();
+    private Map<String,ExpiresConfiguration> expiresConfigurationByContentType = new LinkedHashMap<>();
 
     @Override
     public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
@@ -1343,7 +1346,7 @@ public class ExpiresFilter extends FilterBase {
         return calendar.getTime();
     }
 
-    public Map<String, ExpiresConfiguration> getExpiresConfigurationByContentType() {
+    public Map<String,ExpiresConfiguration> getExpiresConfigurationByContentType() {
         return expiresConfigurationByContentType;
     }
 
@@ -1360,8 +1363,8 @@ public class ExpiresFilter extends FilterBase {
 
             try {
                 if (name.startsWith(PARAMETER_EXPIRES_BY_TYPE)) {
-                    String contentType = name.substring(PARAMETER_EXPIRES_BY_TYPE.length()).trim()
-                            .toLowerCase(Locale.ENGLISH);
+                    String contentType =
+                            name.substring(PARAMETER_EXPIRES_BY_TYPE.length()).trim().toLowerCase(Locale.ENGLISH);
                     ExpiresConfiguration expiresConfiguration = parseExpiresConfiguration(value);
                     this.expiresConfigurationByContentType.put(contentType, expiresConfiguration);
                 } else if (name.equalsIgnoreCase(PARAMETER_EXPIRES_DEFAULT)) {
@@ -1377,7 +1380,9 @@ public class ExpiresFilter extends FilterBase {
             }
         }
 
-        log.debug(sm.getString("expiresFilter.filterInitialized", this.toString()));
+        if (log.isTraceEnabled()) {
+            log.trace(sm.getString("expiresFilter.filterInitialized", this.toString()));
+        }
     }
 
     /**
@@ -1392,8 +1397,8 @@ public class ExpiresFilter extends FilterBase {
      */
     protected boolean isEligibleToExpirationHeaderGeneration(HttpServletRequest request,
             XHttpServletResponse response) {
-        boolean expirationHeaderHasBeenSet = response.containsHeader(HEADER_EXPIRES) ||
-                contains(response.getCacheControlHeader(), "max-age");
+        boolean expirationHeaderHasBeenSet =
+                response.containsHeader(HEADER_EXPIRES) || contains(response.getCacheControlHeader(), "max-age");
         if (expirationHeaderHasBeenSet) {
             if (log.isDebugEnabled()) {
                 log.debug(sm.getString("expiresFilter.expirationHeaderAlreadyDefined", request.getRequestURI(),
@@ -1454,8 +1459,8 @@ public class ExpiresFilter extends FilterBase {
             String maxAgeDirective = "max-age=" + ((expirationDate.getTime() - System.currentTimeMillis()) / 1000);
 
             String cacheControlHeader = response.getCacheControlHeader();
-            String newCacheControlHeader = (cacheControlHeader == null) ? maxAgeDirective
-                    : cacheControlHeader + ", " + maxAgeDirective;
+            String newCacheControlHeader =
+                    (cacheControlHeader == null) ? maxAgeDirective : cacheControlHeader + ", " + maxAgeDirective;
             response.setHeader(HEADER_CACHE_CONTROL, newCacheControlHeader);
             response.setDateHeader(HEADER_EXPIRES, expirationDate.getTime());
         }
@@ -1573,7 +1578,7 @@ public class ExpiresFilter extends FilterBase {
     }
 
     public void setExpiresConfigurationByContentType(
-            Map<String, ExpiresConfiguration> expiresConfigurationByContentType) {
+            Map<String,ExpiresConfiguration> expiresConfigurationByContentType) {
         this.expiresConfigurationByContentType = expiresConfigurationByContentType;
     }
 
