@@ -51,7 +51,11 @@ import org.apache.tomcat.util.res.StringManager;
  * <li>Only connects to port 80</li>
  * <li>Unknown issue means it doesn't work</li>
  * </ul>
+ *
+ * @deprecated This will be removed in Tomcat 11 onwards. This filter is no longer required. The WebDAV client in
+ *             Windows 10 / Windows Server 2012 onwards works correctly without this filter.
  */
+@Deprecated
 public class WebdavFixFilter extends GenericFilter {
 
     private static final long serialVersionUID = 1L;
