@@ -211,24 +211,25 @@ public class StatusTransformer {
 
             writer.write("</jvm>");
         } else if (mode == 2) {
-            writer.append('"').append("jvm").append('"').append(':').append('{').println();
+            indent(writer, 1).append('"').append("jvm").append('"').append(':').append('{').println();
 
-            writer.append('"').append("memory").append('"').append(':').append('{');
+            indent(writer, 2).append('"').append("memory").append('"').append(':').append('{');
             appendJSonValue(writer, "free", Long.toString(Runtime.getRuntime().freeMemory())).append(',');
             appendJSonValue(writer, "total", Long.toString(Runtime.getRuntime().totalMemory())).append(',');
             appendJSonValue(writer, "max", Long.toString(Runtime.getRuntime().maxMemory()));
             writer.append('}').append(',').println();
 
-            writer.append('"').append("memorypool").append('"').append(':').append('[');
+            indent(writer, 2).append('"').append("memorypool").append('"').append(':').append('[');
             boolean first = true;
             for (MemoryPoolMXBean memoryPoolMBean : memoryPoolMBeans.values()) {
                 MemoryUsage usage = memoryPoolMBean.getUsage();
                 if (first) {
                     first = false;
+                    writer.println();
                 } else {
                     writer.append(',').println();
                 }
-                writer.append('{');
+                indent(writer, 3).append('{');
                 appendJSonValue(writer, "name", JSONFilter.escape(memoryPoolMBean.getName())).append(',');
                 appendJSonValue(writer, "type", memoryPoolMBean.getType().toString()).append(',');
                 appendJSonValue(writer, "usageInit", Long.toString(usage.getInit())).append(',');
@@ -237,9 +238,10 @@ public class StatusTransformer {
                 appendJSonValue(writer, "usageUsed", Long.toString(usage.getUsed()));
                 writer.append('}');
             }
-            writer.append(']').println();
+            writer.println();
+            indent(writer, 2).append(']').println();
 
-            writer.append('}');
+            indent(writer, 1).append('}');
         }
 
     }
@@ -250,6 +252,14 @@ public class StatusTransformer {
     }
 
 
+    private static PrintWriter indent(PrintWriter writer, int count) {
+        for (int i = 0; i < count; i++) {
+            writer.append(' ').append(' ');
+        }
+        return writer;
+    }
+
+
     /**
      * Write connector state.
      *
@@ -263,13 +273,12 @@ public class StatusTransformer {
      *
      * @throws Exception Propagated JMX error
      */
-    public static void writeConnectorsState(PrintWriter writer, MBeanServer mBeanServer,
-            List<ObjectName> threadPools,
+    public static void writeConnectorsState(PrintWriter writer, MBeanServer mBeanServer, List<ObjectName> threadPools,
             List<ObjectName> globalRequestProcessors, List<ObjectName> requestProcessors, int mode, Object[] args)
             throws Exception {
         if (mode == 2) {
             writer.append(',').println();
-            writer.append('"').append("connector").append('"').append(':').append('[').println();
+            indent(writer, 1).append('"').append("connector").append('"').append(':').append('[').println();
         }
         boolean first = true;
         for (ObjectName objectName : threadPools) {
@@ -282,11 +291,11 @@ public class StatusTransformer {
             }
             String name = objectName.getKeyProperty("name");
             // use StatusTransformer to output status
-            writeConnectorState(
-                    writer, objectName, name, mBeanServer, globalRequestProcessors, requestProcessors, mode, args);
+            writeConnectorState(writer, objectName, name, mBeanServer, globalRequestProcessors, requestProcessors, mode,
+                    args);
         }
         if (mode == 2) {
-            writer.append(']').println();
+            writer.append(']');
         }
     }
 
@@ -428,13 +437,21 @@ public class StatusTransformer {
 
             writer.write("</connector>");
         } else if (mode == 2) {
-            writer.append('{').println();
+            indent(writer, 2).append('{').println();
 
-            appendJSonValue(writer, "name", JSONFilter.escape(name)).append(',').println();
-            writer.append('"').append("threadInfo").append('"').append(':').append('{');
-            appendJSonValue(writer, "maxThreads", mBeanServer.getAttribute(tpName, "maxThreads").toString()).append(',');
-            appendJSonValue(writer, "currentThreadCount", mBeanServer.getAttribute(tpName, "currentThreadCount").toString()).append(',');
-            appendJSonValue(writer, "currentThreadsBusy", mBeanServer.getAttribute(tpName, "currentThreadsBusy").toString());
+            indent(writer, 3);
+            String jsonName = JSONFilter.escape(name);
+            if (jsonName.length() > 4 && jsonName.startsWith("\\\"") && jsonName.endsWith("\\\"")) {
+                jsonName = jsonName.substring(2, jsonName.length() - 2);
+            }
+            appendJSonValue(writer, "name", jsonName).append(',').println();
+            indent(writer, 3).append('"').append("threadInfo").append('"').append(':').append('{');
+            appendJSonValue(writer, "maxThreads", mBeanServer.getAttribute(tpName, "maxThreads").toString())
+                    .append(',');
+            appendJSonValue(writer, "currentThreadCount",
+                    mBeanServer.getAttribute(tpName, "currentThreadCount").toString()).append(',');
+            appendJSonValue(writer, "currentThreadsBusy",
+                    mBeanServer.getAttribute(tpName, "currentThreadsBusy").toString());
             writer.append('}');
 
             ObjectName grpName = null;
@@ -447,18 +464,22 @@ public class StatusTransformer {
 
             if (grpName != null) {
                 writer.append(',').println();
-                writer.append('"').append("requestInfo").append('"').append(':').append('{');
+                indent(writer, 3).append('"').append("requestInfo").append('"').append(':').append('{');
                 appendJSonValue(writer, "maxTime", mBeanServer.getAttribute(grpName, "maxTime").toString()).append(',');
-                appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(grpName, "processingTime").toString()).append(',');
-                appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(grpName, "requestCount").toString()).append(',');
-                appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(grpName, "errorCount").toString()).append(',');
-                appendJSonValue(writer, "bytesReceived", mBeanServer.getAttribute(grpName, "bytesReceived").toString()).append(',');
+                appendJSonValue(writer, "processingTime",
+                        mBeanServer.getAttribute(grpName, "processingTime").toString()).append(',');
+                appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(grpName, "requestCount").toString())
+                        .append(',');
+                appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(grpName, "errorCount").toString())
+                        .append(',');
+                appendJSonValue(writer, "bytesReceived", mBeanServer.getAttribute(grpName, "bytesReceived").toString())
+                        .append(',');
                 appendJSonValue(writer, "bytesSent", mBeanServer.getAttribute(grpName, "bytesSent").toString());
                 writer.append('}').println();
                 // Note: No detailed per processor info
             }
 
-            writer.append('}');
+            indent(writer, 2).append('}');
         }
     }
 
@@ -692,7 +713,7 @@ public class StatusTransformer {
             // for now we don't write out the Detailed state in XML
         } else if (mode == 2) {
             writer.append(',').println();
-            writer.append('"').append("context").append('"').append(':').append('[');
+            indent(writer, 1).append('"').append("context").append('"').append(':').append('[').println();
             Iterator<ObjectName> iterator = hostsON.iterator();
             boolean first = true;
             while (iterator.hasNext()) {
@@ -704,7 +725,8 @@ public class StatusTransformer {
                 ObjectName contextON = iterator.next();
                 writeContext(writer, contextON, mBeanServer, mode);
             }
-            writer.append(']').println();
+            writer.println();
+            indent(writer, 1).append(']').println();
         }
 
     }
@@ -791,11 +813,13 @@ public class StatusTransformer {
         } else if (mode == 1) {
             // for now we don't write out the context in XML
         } else if (mode == 2) {
-            writer.append('{');
-            appendJSonValue(writer, "name", JSONFilter.escape(JSONFilter.escape(name))).append(',');
+            indent(writer, 2).append('{').println();
+            appendJSonValue(indent(writer, 3), "name", JSONFilter.escape(JSONFilter.escape(name))).append(',');
             appendJSonValue(writer, "startTime",
-                    new Date(((Long) mBeanServer.getAttribute(objectName, "startTime")).longValue()).toString()).append(',');
-            appendJSonValue(writer, "startupTime", mBeanServer.getAttribute(objectName, "startupTime").toString()).append(',');
+                    new Date(((Long) mBeanServer.getAttribute(objectName, "startTime")).longValue()).toString())
+                    .append(',');
+            appendJSonValue(writer, "startupTime", mBeanServer.getAttribute(objectName, "startupTime").toString())
+                    .append(',');
             appendJSonValue(writer, "tldScanTime", mBeanServer.getAttribute(objectName, "tldScanTime").toString());
             if (managerON != null) {
                 writeManager(writer, managerON, mBeanServer, mode);
@@ -804,7 +828,7 @@ public class StatusTransformer {
                 writeJspMonitor(writer, jspMonitorONs, mBeanServer, mode);
             }
             writer.append(',').println();
-            writer.append('"').append("wrapper").append('"').append(':').append('[');
+            indent(writer, 3).append('"').append("wrapper").append('"').append(':').append('[').println();
             String onStr = objectName.getDomain() + ":j2eeType=Servlet,WebModule=" + webModuleName + ",*";
             ObjectName servletObjectName = new ObjectName(onStr);
             Set<ObjectInstance> set = mBeanServer.queryMBeans(servletObjectName, null);
@@ -817,8 +841,9 @@ public class StatusTransformer {
                 }
                 writeWrapper(writer, oi.getObjectName(), mBeanServer, mode);
             }
-            writer.append(']').println();
-            writer.append('}');
+            writer.println();
+            indent(writer, 3).append(']').println();
+            indent(writer, 2).append('}');
         }
 
     }
@@ -859,15 +884,23 @@ public class StatusTransformer {
             // for now we don't write out the wrapper details
         } else if (mode == 2) {
             writer.append(',').println();
-            writer.append('"').append("manager").append('"').append(':').append('{');
-            appendJSonValue(writer, "activeSessions", mBeanServer.getAttribute(objectName, "activeSessions").toString()).append(',');
-            appendJSonValue(writer, "sessionCounter", mBeanServer.getAttribute(objectName, "sessionCounter").toString()).append(',');
-            appendJSonValue(writer, "maxActive", mBeanServer.getAttribute(objectName, "maxActive").toString()).append(',');
-            appendJSonValue(writer, "rejectedSessions", mBeanServer.getAttribute(objectName, "rejectedSessions").toString()).append(',');
-            appendJSonValue(writer, "expiredSessions", mBeanServer.getAttribute(objectName, "expiredSessions").toString()).append(',');
-            appendJSonValue(writer, "sessionMaxAliveTime", mBeanServer.getAttribute(objectName, "sessionMaxAliveTime").toString()).append(',');
-            appendJSonValue(writer, "sessionAverageAliveTime", mBeanServer.getAttribute(objectName, "sessionAverageAliveTime").toString()).append(',');
-            appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(objectName, "processingTime").toString());
+            indent(writer, 3).append('"').append("manager").append('"').append(':').append('{');
+            appendJSonValue(writer, "activeSessions", mBeanServer.getAttribute(objectName, "activeSessions").toString())
+                    .append(',');
+            appendJSonValue(writer, "sessionCounter", mBeanServer.getAttribute(objectName, "sessionCounter").toString())
+                    .append(',');
+            appendJSonValue(writer, "maxActive", mBeanServer.getAttribute(objectName, "maxActive").toString())
+                    .append(',');
+            appendJSonValue(writer, "rejectedSessions",
+                    mBeanServer.getAttribute(objectName, "rejectedSessions").toString()).append(',');
+            appendJSonValue(writer, "expiredSessions",
+                    mBeanServer.getAttribute(objectName, "expiredSessions").toString()).append(',');
+            appendJSonValue(writer, "sessionMaxAliveTime",
+                    mBeanServer.getAttribute(objectName, "sessionMaxAliveTime").toString()).append(',');
+            appendJSonValue(writer, "sessionAverageAliveTime",
+                    mBeanServer.getAttribute(objectName, "sessionAverageAliveTime").toString()).append(',');
+            appendJSonValue(writer, "processingTime",
+                    mBeanServer.getAttribute(objectName, "processingTime").toString());
             writer.append('}');
         }
 
@@ -907,7 +940,7 @@ public class StatusTransformer {
             // for now we don't write out anything
         } else if (mode == 2) {
             writer.append(',').println();
-            writer.append('"').append("jsp").append('"').append(':').append('{');
+            indent(writer, 3).append('"').append("jsp").append('"').append(':').append('{');
             appendJSonValue(writer, "jspCount", Integer.toString(jspCount)).append(',');
             appendJSonValue(writer, "jspReloadCount", Integer.toString(jspReloadCount));
             writer.append('}');
@@ -964,13 +997,17 @@ public class StatusTransformer {
         } else if (mode == 1) {
             // for now we don't write out the wrapper details
         } else if (mode == 2) {
-            writer.append('{');
+            indent(writer, 4).append('{');
             appendJSonValue(writer, "servletName", JSONFilter.escape(servletName)).append(',');
-            appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(objectName, "processingTime").toString()).append(',');
+            appendJSonValue(writer, "processingTime", mBeanServer.getAttribute(objectName, "processingTime").toString())
+                    .append(',');
             appendJSonValue(writer, "maxTime", mBeanServer.getAttribute(objectName, "maxTime").toString()).append(',');
-            appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(objectName, "requestCount").toString()).append(',');
-            appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(objectName, "errorCount").toString()).append(',');
-            appendJSonValue(writer, "loadTime", mBeanServer.getAttribute(objectName, "loadTime").toString()).append(',');
+            appendJSonValue(writer, "requestCount", mBeanServer.getAttribute(objectName, "requestCount").toString())
+                    .append(',');
+            appendJSonValue(writer, "errorCount", mBeanServer.getAttribute(objectName, "errorCount").toString())
+                    .append(',');
+            appendJSonValue(writer, "loadTime", mBeanServer.getAttribute(objectName, "loadTime").toString())
+                    .append(',');
             appendJSonValue(writer, "classLoadTime", mBeanServer.getAttribute(objectName, "classLoadTime").toString());
             writer.append('}');
         }
