@@ -126,20 +126,12 @@ public class HostManagerServlet extends HttpServlet implements ContainerServlet
     // ----------------------------------------------- ContainerServlet Methods
 
 
-    /**
-     * Return the Wrapper with which we are associated.
-     */
     @Override
     public Wrapper getWrapper() {
         return this.wrapper;
     }
 
 
-    /**
-     * Set the Wrapper with which we are associated.
-     *
-     * @param wrapper The new wrapper
-     */
     @Override
     public void setWrapper(Wrapper wrapper) {
 
@@ -159,9 +151,6 @@ public class HostManagerServlet extends HttpServlet implements ContainerServlet
     // --------------------------------------------------------- Public Methods
 
 
-    /**
-     * Finalize this servlet.
-     */
     @Override
     public void destroy() {
 
@@ -170,15 +159,6 @@ public class HostManagerServlet extends HttpServlet implements ContainerServlet
     }
 
 
-    /**
-     * Process a GET request for the specified resource.
-     *
-     * @param request  The servlet request we are processing
-     * @param response The servlet response we are creating
-     *
-     * @exception IOException      if an input/output error occurs
-     * @exception ServletException if a servlet-specified error occurs
-     */
     @Override
     public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException, ServletException {
 
@@ -622,7 +602,7 @@ public class HostManagerServlet extends HttpServlet implements ContainerServlet
             // catch InstanceNotFoundException when StoreConfig is not enabled instead of printing
             // the failure message
             if (e instanceof InstanceNotFoundException) {
-                writer.println("Please enable StoreConfig to use this feature.");
+                writer.println(smClient.getString("hostManagerServlet.noStoreConfig"));
             } else {
                 writer.println(smClient.getString("hostManagerServlet.exception", e.toString()));
             }
