@@ -821,22 +821,22 @@ public final class CGIServlet extends HttpServlet {
                 webAppRootDir = webAppRootDir + File.separator + cgiPathPrefix;
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("cgiServlet.find.path", pathInfo, webAppRootDir));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("cgiServlet.find.path", pathInfo, webAppRootDir));
             }
 
             File currentLocation = new File(webAppRootDir);
             StringTokenizer dirWalker = new StringTokenizer(pathInfo, "/");
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("cgiServlet.find.location", currentLocation.getAbsolutePath()));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("cgiServlet.find.location", currentLocation.getAbsolutePath()));
             }
             StringBuilder cginameBuilder = new StringBuilder();
             while (!currentLocation.isFile() && dirWalker.hasMoreElements()) {
                 String nextElement = (String) dirWalker.nextElement();
                 currentLocation = new File(currentLocation, nextElement);
                 cginameBuilder.append('/').append(nextElement);
-                if (log.isDebugEnabled()) {
-                    log.debug(sm.getString("cgiServlet.find.location", currentLocation.getAbsolutePath()));
+                if (log.isTraceEnabled()) {
+                    log.trace(sm.getString("cgiServlet.find.location", currentLocation.getAbsolutePath()));
                 }
             }
             String cginame = cginameBuilder.toString();
@@ -853,8 +853,8 @@ public final class CGIServlet extends HttpServlet {
                 scriptname = contextPath + servletPath + cginame;
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("cgiServlet.find.found", name, path, scriptname, cginame));
+            if (log.isTraceEnabled()) {
+                log.trace(sm.getString("cgiServlet.find.found", name, path, scriptname, cginame));
             }
             return new String[] { path, scriptname, cginame, name };
         }
@@ -1433,17 +1433,16 @@ public final class CGIServlet extends HttpServlet {
              */
 
             if (!isReady()) {
-                throw new IOException(this.getClass().getName() + ": not ready to run.");
+                throw new IOException(sm.getString("cgiServlet.notReady"));
             }
 
-            if (log.isDebugEnabled()) {
-                log.debug("envp: [" + env + "], command: [" + command + "]");
+            if (log.isTraceEnabled()) {
+                log.trace("envp: [" + env + "], command: [" + command + "]");
             }
 
             if ((command.contains(File.separator + "." + File.separator)) ||
                     (command.contains(File.separator + "..")) || (command.contains(".." + File.separator))) {
-                throw new IOException(this.getClass().getName() + "Illegal Character in CGI command path " +
-                        "('.' or '..') detected.  Not running CGI [" + command + "].");
+                throw new IOException(sm.getString("cgiServlet.invalidCommand", command));
             }
 
             /*
