@@ -139,9 +139,6 @@ public class DataSourceStore extends StoreBase {
         return name;
     }
 
-    /**
-     * @return the name for this Store, used for logging.
-     */
     @Override
     public String getStoreName() {
         return storeName;
@@ -366,7 +363,7 @@ public class DataSourceStore extends StoreBase {
                     }
                 }
             } catch (SQLException e) {
-                manager.getContext().getLogger().error(sm.getString(getStoreName() + ".SQLException", e));
+                manager.getContext().getLogger().error(sm.getString("dataSourceStore.SQLException", e));
                 keys = new String[0];
                 // Close the connection so that it gets reopened next time
             } finally {
@@ -377,14 +374,6 @@ public class DataSourceStore extends StoreBase {
         return keys;
     }
 
-    /**
-     * Return an integer containing a count of all Sessions currently saved in this Store. If there are no Sessions,
-     * <code>0</code> is returned.
-     *
-     * @return the count of all sessions currently saved in this Store
-     *
-     * @exception IOException if an input/output error occurred
-     */
     @Override
     public int getSize() throws IOException {
         int size = 0;
@@ -408,7 +397,7 @@ public class DataSourceStore extends StoreBase {
                     numberOfTries = 0;
                 }
             } catch (SQLException e) {
-                manager.getContext().getLogger().error(sm.getString(getStoreName() + ".SQLException", e));
+                manager.getContext().getLogger().error(sm.getString("dataSourceStore.SQLException", e));
             } finally {
                 release(_conn);
             }
@@ -417,17 +406,6 @@ public class DataSourceStore extends StoreBase {
         return size;
     }
 
-    /**
-     * Load the Session associated with the id <code>id</code>. If no such session is found <code>null</code> is
-     * returned.
-     *
-     * @param id a value of type <code>String</code>
-     *
-     * @return the stored <code>Session</code>
-     *
-     * @exception ClassNotFoundException if an error occurs
-     * @exception IOException            if an input/output error occurred
-     */
     @Override
     public Session load(String id) throws ClassNotFoundException, IOException {
         StandardSession _session = null;
@@ -451,8 +429,8 @@ public class DataSourceStore extends StoreBase {
                 try (ResultSet rst = preparedLoadSql.executeQuery()) {
                     if (rst.next()) {
                         try (ObjectInputStream ois = getObjectInputStream(rst.getBinaryStream(2))) {
-                            if (contextLog.isDebugEnabled()) {
-                                contextLog.debug(sm.getString(getStoreName() + ".loading", id, sessionTable));
+                            if (contextLog.isTraceEnabled()) {
+                                contextLog.trace(sm.getString("dataSourceStore.loading", id, sessionTable));
                             }
 
                             _session = (StandardSession) manager.createEmptySession();
@@ -460,13 +438,13 @@ public class DataSourceStore extends StoreBase {
                             _session.setManager(manager);
                         }
                     } else if (context.getLogger().isDebugEnabled()) {
-                        contextLog.debug(getStoreName() + ": No persisted data object found");
+                        contextLog.debug(sm.getString("dataSourceStore.noObject", id));
                     }
                     // Break out after the finally block
                     numberOfTries = 0;
                 }
             } catch (SQLException e) {
-                contextLog.error(sm.getString(getStoreName() + ".SQLException", e));
+                contextLog.error(sm.getString("dataSourceStore.SQLException", e));
             } finally {
                 context.unbind(Globals.IS_SECURITY_ENABLED, oldThreadContextCL);
                 release(_conn);
@@ -476,14 +454,6 @@ public class DataSourceStore extends StoreBase {
         return _session;
     }
 
-    /**
-     * Remove the Session with the specified session identifier from this Store, if present. If no such Session is
-     * present, this method takes no action.
-     *
-     * @param id Session identifier of the Session to be removed
-     *
-     * @exception IOException if an input/output error occurs
-     */
     @Override
     public void remove(String id) throws IOException {
 
@@ -500,15 +470,15 @@ public class DataSourceStore extends StoreBase {
                 // Break out after the finally block
                 numberOfTries = 0;
             } catch (SQLException e) {
-                manager.getContext().getLogger().error(sm.getString(getStoreName() + ".SQLException", e));
+                manager.getContext().getLogger().error(sm.getString("dataSourceStore.SQLException", e));
             } finally {
                 release(_conn);
             }
             numberOfTries--;
         }
 
-        if (manager.getContext().getLogger().isDebugEnabled()) {
-            manager.getContext().getLogger().debug(sm.getString(getStoreName() + ".removing", id, sessionTable));
+        if (manager.getContext().getLogger().isTraceEnabled()) {
+            manager.getContext().getLogger().trace(sm.getString("dataSourceStore.removing", id, sessionTable));
         }
     }
 
@@ -531,11 +501,6 @@ public class DataSourceStore extends StoreBase {
         }
     }
 
-    /**
-     * Remove all of the Sessions in this Store.
-     *
-     * @exception IOException if an input/output error occurs
-     */
     @Override
     public void clear() throws IOException {
         String clearSql = "DELETE FROM " + sessionTable + " WHERE " + sessionAppCol + " = ?";
@@ -553,7 +518,7 @@ public class DataSourceStore extends StoreBase {
                 // Break out after the finally block
                 numberOfTries = 0;
             } catch (SQLException e) {
-                manager.getContext().getLogger().error(sm.getString(getStoreName() + ".SQLException", e));
+                manager.getContext().getLogger().error(sm.getString("dataSourceStore.SQLException", e));
             } finally {
                 release(_conn);
             }
@@ -561,13 +526,6 @@ public class DataSourceStore extends StoreBase {
         }
     }
 
-    /**
-     * Save a session to the Store.
-     *
-     * @param session the session to be stored
-     *
-     * @exception IOException if an input/output error occurs
-     */
     @Override
     public void save(Session session) throws IOException {
         ByteArrayOutputStream bos = null;
@@ -609,7 +567,7 @@ public class DataSourceStore extends StoreBase {
                         numberOfTries = 0;
                     }
                 } catch (SQLException e) {
-                    manager.getContext().getLogger().error(sm.getString(getStoreName() + ".SQLException", e));
+                    manager.getContext().getLogger().error(sm.getString("dataSourceStore.SQLException", e));
                 } catch (IOException e) {
                     // Ignore
                 } finally {
@@ -619,9 +577,9 @@ public class DataSourceStore extends StoreBase {
             }
         }
 
-        if (manager.getContext().getLogger().isDebugEnabled()) {
+        if (manager.getContext().getLogger().isTraceEnabled()) {
             manager.getContext().getLogger()
-                    .debug(sm.getString(getStoreName() + ".saving", session.getIdInternal(), sessionTable));
+                    .trace(sm.getString("dataSourceStore.saving", session.getIdInternal(), sessionTable));
         }
     }
 
@@ -639,16 +597,14 @@ public class DataSourceStore extends StoreBase {
         try {
             conn = open();
             if (conn == null || conn.isClosed()) {
-                manager.getContext().getLogger().info(sm.getString(getStoreName() + ".checkConnectionDBClosed"));
+                manager.getContext().getLogger().info(sm.getString("dataSourceStore.checkConnectionDBClosed"));
                 conn = open();
                 if (conn == null || conn.isClosed()) {
-                    manager.getContext().getLogger()
-                            .info(sm.getString(getStoreName() + ".checkConnectionDBReOpenFail"));
+                    manager.getContext().getLogger().info(sm.getString("dataSourceStore.checkConnectionDBReOpenFail"));
                 }
             }
         } catch (SQLException ex) {
-            manager.getContext().getLogger()
-                    .error(sm.getString(getStoreName() + ".checkConnectionSQLException", ex.toString()));
+            manager.getContext().getLogger().error(sm.getString("dataSourceStore.checkConnectionSQLException", ex));
         }
 
         return conn;
@@ -675,7 +631,7 @@ public class DataSourceStore extends StoreBase {
                 Context envCtx = (Context) initCtx.lookup("java:comp/env");
                 this.dataSource = (DataSource) envCtx.lookup(this.dataSourceName);
             } catch (NamingException e) {
-                context.getLogger().error(sm.getString(getStoreName() + ".wrongDataSource", this.dataSourceName), e);
+                context.getLogger().error(sm.getString("dataSourceStore.wrongDataSource", this.dataSourceName), e);
             } finally {
                 if (getLocalDataSource()) {
                     context.unbind(Globals.IS_SECURITY_ENABLED, oldThreadContextCL);
@@ -686,7 +642,7 @@ public class DataSourceStore extends StoreBase {
         if (dataSource != null) {
             return dataSource.getConnection();
         } else {
-            throw new IllegalStateException(sm.getString(getStoreName() + ".missingDataSource"));
+            throw new IllegalStateException(sm.getString("dataSourceStore.missingDataSource"));
         }
     }
 
@@ -708,15 +664,14 @@ public class DataSourceStore extends StoreBase {
                 dbConnection.commit();
             }
         } catch (SQLException e) {
-            manager.getContext().getLogger().error(sm.getString(getStoreName() + ".commitSQLException"), e);
+            manager.getContext().getLogger().error(sm.getString("dataSourceStore.commitSQLException"), e);
         }
 
         // Close this database connection, and log any errors
         try {
             dbConnection.close();
         } catch (SQLException e) {
-            manager.getContext().getLogger().error(sm.getString(getStoreName() + ".close", e.toString())); // Just log
-                                                                                                           // it here
+            manager.getContext().getLogger().error(sm.getString("dataSourceStore.close", e));
         }
     }
 
