@@ -427,15 +427,6 @@ public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
     // --------------------------------------------------------- Public Methods
 
 
-    /**
-     * This method is invoked by Tomcat on each query.
-     *
-     * @param request  The Request object.
-     * @param response The Response object.
-     *
-     * @exception IOException      Should not be thrown.
-     * @exception ServletException Database SQLException is wrapped in a ServletException.
-     */
     @Override
     public void invoke(Request request, Response response) throws IOException, ServletException {
         getNext().invoke(request, response);
@@ -622,7 +613,7 @@ public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *                                   used
      */
     @Override
-    protected synchronized void startInternal() throws LifecycleException {
+    protected void startInternal() throws LifecycleException {
         try {
             open();
         } catch (SQLException e) {
@@ -640,7 +631,7 @@ public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *                                   used
      */
     @Override
-    protected synchronized void stopInternal() throws LifecycleException {
+    protected void stopInternal() throws LifecycleException {
         super.stopInternal();
         close();
     }
