@@ -209,7 +209,7 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
                 }
             } catch (IOException ioe) {
                 if (getLog().isDebugEnabled()) {
-                    getLog().debug("Unable to write async data.", ioe);
+                    getLog().debug(sm.getString("abstractProcessor.asyncFail"), ioe);
                 }
                 status = SocketEvent.ERROR;
                 request.setAttribute(RequestDispatcher.ERROR_EXCEPTION, ioe);
@@ -265,8 +265,8 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
             state = dispatchEndRequest();
         }
 
-        if (getLog().isDebugEnabled()) {
-            getLog().debug("Socket: [" + socketWrapper + "], Status in: [" + status + "], State out: [" + state + "]");
+        if (getLog().isTraceEnabled()) {
+            getLog().trace("Socket: [" + socketWrapper + "], Status in: [" + status + "], State out: [" + state + "]");
         }
 
         return state;
@@ -721,27 +721,60 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
     }
 
 
+    /**
+     * When committing the response, we have to validate the set of headers, as well as setup the response filters.
+     * @throws IOException IO exception during commit
+     */
     protected abstract void prepareResponse() throws IOException;
 
 
+    /**
+     * Finish the current response.
+     * @throws IOException IO exception during the write
+     */
     protected abstract void finishResponse() throws IOException;
 
 
+    /**
+     * Process acknowledgment of the request.
+     * @param continueResponseTiming specifies when an acknowledgment should be sent
+     */
     protected abstract void ack(ContinueResponseTiming continueResponseTiming);
 
 
+    /**
+     * Callback to write data from the buffer.
+     * @throws IOException IO exception during the write
+     */
     protected abstract void flush() throws IOException;
 
 
+    /**
+     * Queries if bytes are available in buffers.
+     * @param doRead {@code true} to perform a read when no bytes are availble
+     * @return the amount of bytes that are known to be available
+     */
     protected abstract int available(boolean doRead);
 
 
+    /**
+     * Set the specified byte chunk as the request body that will be read. This allows saving and
+     * processing requests.
+     * @param body the byte chunk containing all the request bytes
+     */
     protected abstract void setRequestBody(ByteChunk body);
 
 
+    /**
+     * The response is finished and no additional bytes need to be sent to the client.
+     */
     protected abstract void setSwallowResponse();
 
 
+    /**
+     * Swallowing bytes is required for pipelining requests, so this allows to avoid doing extra operations
+     * in case an error occurs and the connection is to be closed instead.
+     */
     protected abstract void disableSwallowRequest();
 
 
@@ -844,12 +877,22 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
     }
 
 
+    /**
+     * @return {@code true} if it is known that the request body has been fully read
+     */
     protected abstract boolean isRequestBodyFullyRead();
 
 
+    /**
+     * When using non blocking IO, register to get a callback when polling determines that bytes
+     * are available for reading.
+     */
     protected abstract void registerReadInterest();
 
 
+    /**
+     * @return {@code true} if bytes can be written without blocking
+     */
     protected abstract boolean isReadyForWrite();
 
 
