@@ -579,6 +579,8 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
 
     /**
      * Parse the HTTP headers.
+     *
+     * @throws IOException an underlying I/O error occurred
      */
     boolean parseHeaders() throws IOException {
         if (!parsingHeader) {
@@ -656,6 +658,7 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
     /**
      * Available bytes in the buffers for the current request. Note that when requests are pipelined, the data in
      * byteBuffer may relate to the next request rather than this one.
+     * @return the amount of bytes available, 0 if none, and 1 if there was an IO error to trigger a read
      */
     int available(boolean read) {
         int available;
@@ -698,6 +701,7 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
     /**
      * Has all of the request body been read? There are subtle differences between this and available() &gt; 0 primarily
      * because of having to handle faking non-blocking reads with the blocking IO connector.
+     * @return {@code true} if the request has been fully read
      */
     boolean isFinished() {
         // The active filters have the definitive information on whether or not
@@ -754,8 +758,8 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
      */
     private boolean fill(boolean block) throws IOException {
 
-        if (log.isDebugEnabled()) {
-            log.debug("Before fill(): parsingHeader: [" + parsingHeader + "], parsingRequestLine: [" +
+        if (log.isTraceEnabled()) {
+            log.trace("Before fill(): parsingHeader: [" + parsingHeader + "], parsingRequestLine: [" +
                     parsingRequestLine + "], parsingRequestLinePhase: [" + parsingRequestLinePhase +
                     "], parsingRequestLineStart: [" + parsingRequestLineStart + "], byteBuffer.position(): [" +
                     byteBuffer.position() + "], byteBuffer.limit(): [" + byteBuffer.limit() + "], end: [" + end + "]");
@@ -806,8 +810,8 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
             }
         }
 
-        if (log.isDebugEnabled()) {
-            log.debug("Received [" + new String(byteBuffer.array(), byteBuffer.position(), byteBuffer.remaining(),
+        if (log.isTraceEnabled()) {
+            log.trace("Received [" + new String(byteBuffer.array(), byteBuffer.position(), byteBuffer.remaining(),
                     StandardCharsets.ISO_8859_1) + "]");
         }
 
