@@ -169,7 +169,7 @@ public class Http11Processor extends AbstractProcessor {
 
         // Create and add the chunked filters.
         inputBuffer.addFilter(
-                new ChunkedInputFilter(protocol.getMaxTrailerSize(), protocol.getAllowedTrailerHeadersInternal(),
+                new ChunkedInputFilter(request, protocol.getMaxTrailerSize(), protocol.getAllowedTrailerHeadersInternal(),
                         protocol.getMaxExtensionSize(), protocol.getMaxSwallowSize()));
         outputBuffer.addFilter(new ChunkedOutputFilter());
 
@@ -212,8 +212,7 @@ public class Http11Processor extends AbstractProcessor {
             response.setStatus(400);
             setErrorState(ErrorState.CLOSE_CLEAN, null);
             if (log.isDebugEnabled()) {
-                log.debug(sm.getString("http11processor.request.prepare") +
-                        " Transfer encoding lists chunked before [" + encodingName + "]");
+                log.debug(sm.getString("http11processor.request.alreadyChunked", encodingName));
             }
             return;
         }
@@ -234,8 +233,7 @@ public class Http11Processor extends AbstractProcessor {
             response.setStatus(501);
             setErrorState(ErrorState.CLOSE_CLEAN, null);
             if (log.isDebugEnabled()) {
-                log.debug(sm.getString("http11processor.request.prepare") + " Unsupported transfer encoding [" +
-                        encodingName + "]");
+                log.debug(sm.getString("http11processor.request.unsupportedEncoding", encodingName));
             }
         }
     }
@@ -613,8 +611,7 @@ public class Http11Processor extends AbstractProcessor {
             response.setStatus(505);
             setErrorState(ErrorState.CLOSE_CLEAN, null);
             if (log.isDebugEnabled()) {
-                log.debug(sm.getString("http11processor.request.prepare") + " Unsupported HTTP version \"" +
-                        protocolMB + "\"");
+                log.debug(sm.getString("http11processor.request.unsupportedVersion", protocolMB));
             }
         }
     }
@@ -734,7 +731,7 @@ public class Http11Processor extends AbstractProcessor {
                     if (hostValueMB != null) {
                         // Any host in the request line must be consistent with
                         // the Host header
-                        if (!hostValueMB.getByteChunk().equals(uriB, uriBCStart + pos, slashPos - pos)) {
+                        if (!hostValueMB.getByteChunk().equalsIgnoreCase(uriB, uriBCStart + pos, slashPos - pos)) {
                             if (protocol.getAllowHostHeaderMismatch()) {
                                 // The requirements of RFC 2616 are being
                                 // applied. If the host header and the request
@@ -870,9 +867,6 @@ public class Http11Processor extends AbstractProcessor {
     }
 
 
-    /**
-     * When committing the response, we have to validate the set of headers, as well as setup the response filters.
-     */
     @Override
     protected final void prepareResponse() throws IOException {
 
@@ -966,7 +960,11 @@ public class Http11Processor extends AbstractProcessor {
             headers.addValue("Date").setString(FastHttpDateFormat.getCurrentDate());
         }
 
-        // FIXME: Add transfer encoding header
+        // Although using transfer-encoding for gzip would be doable and was
+        // the original intent (which means the compression would be from an
+        // endpoint to the next, so only for the current transmission), it
+        // has been found that using content-encoding (which is end to end
+        // compression) is more efficient and more reliable.
 
         if ((entityBody) && (!contentDelimitation) || connectionClosePresent) {
             // Disable keep-alive if:
@@ -1056,7 +1054,8 @@ public class Http11Processor extends AbstractProcessor {
                     size--;
                     // Header buffer is corrupted. Reset it and start again.
                     outputBuffer.resetHeaderBuffer();
-                    i = 0;
+                    // -1 as it will be incremented at the start of the loop and header indexes start at 0.
+                    i = -1;
                     outputBuffer.sendStatus();
                 }
             }
