@@ -26,6 +26,7 @@ import org.apache.coyote.http11.HttpOutputBuffer;
 import org.apache.coyote.http11.OutputFilter;
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
+import org.apache.tomcat.util.res.StringManager;
 
 /**
  * Gzip output filter.
@@ -35,6 +36,7 @@ import org.apache.juli.logging.LogFactory;
 public class GzipOutputFilter implements OutputFilter {
 
     protected static final Log log = LogFactory.getLog(GzipOutputFilter.class);
+    private static final StringManager sm = StringManager.getManager(GzipOutputFilter.class);
 
 
     // ----------------------------------------------------- Instance Variables
@@ -86,19 +88,20 @@ public class GzipOutputFilter implements OutputFilter {
     // --------------------------------------------------- OutputFilter Methods
 
     /**
-     * Added to allow flushing to happen for the gzip'ed outputstream
+     * {@inheritDoc}
+     * Added to allow flushing to happen for the gzip'ed outputstream.
      */
     @Override
     public void flush() throws IOException {
         if (compressionStream != null) {
             try {
-                if (log.isDebugEnabled()) {
-                    log.debug("Flushing the compression stream!");
+                if (log.isTraceEnabled()) {
+                    log.trace("Flushing the compression stream!");
                 }
                 compressionStream.flush();
             } catch (IOException e) {
                 if (log.isDebugEnabled()) {
-                    log.debug("Ignored exception while flushing gzip filter", e);
+                    log.debug(sm.getString("gzipOutputFilter.flushFail"), e);
                 }
             }
         }
@@ -129,9 +132,6 @@ public class GzipOutputFilter implements OutputFilter {
     }
 
 
-    /**
-     * Make the filter ready to process the next request.
-     */
     @Override
     public void recycle() {
         // Set compression stream to null
