@@ -19,7 +19,7 @@ package org.apache.jasper;
 import java.io.File;
 import java.util.Map;
 
-import javax.servlet.jsp.tagext.TagLibraryInfo;
+import jakarta.servlet.jsp.tagext.TagLibraryInfo;
 
 import org.apache.jasper.compiler.JspConfig;
 import org.apache.jasper.compiler.TagPluginManager;
@@ -40,34 +40,34 @@ public interface Options {
      * is invalid.
      * @return <code>true</code> to get an error
      */
-    public boolean getErrorOnUseBeanInvalidClassAttribute();
+    boolean getErrorOnUseBeanInvalidClassAttribute();
 
     /**
      * @return <code>true</code> to keep the generated source
      */
-    public boolean getKeepGenerated();
+    boolean getKeepGenerated();
 
     /**
      * @return <code>true</code> if tag handler pooling is enabled,
      *  <code>false</code> otherwise.
      */
-    public boolean isPoolingEnabled();
+    boolean isPoolingEnabled();
 
     /**
      * @return <code>true</code> if HTML mapped Servlets are supported.
      */
-    public boolean getMappedFile();
+    boolean getMappedFile();
 
     /**
      * @return <code>true</code> if debug information in included
      *  in compiled classes.
      */
-    public boolean getClassDebugInfo();
+    boolean getClassDebugInfo();
 
     /**
      * @return background compile thread check interval in seconds
      */
-    public int getCheckInterval();
+    int getCheckInterval();
 
     /**
      * Main development flag, which enables detailed error reports with
@@ -76,26 +76,26 @@ public interface Options {
      *  in production.
      * @return <code>true</code> if Jasper is in development mode
      */
-    public boolean getDevelopment();
+    boolean getDevelopment();
 
     /**
      * @return <code>true</code> to include a source fragment in exception
      *  messages.
      */
-    public boolean getDisplaySourceFragment();
+    boolean getDisplaySourceFragment();
 
     /**
      * @return <code>true</code> to suppress generation of SMAP info for
      *  JSR45 debugging.
      */
-    public boolean isSmapSuppressed();
+    boolean isSmapSuppressed();
 
     /**
      * This setting is ignored if suppressSmap() is <code>true</code>.
      * @return <code>true</code> to write SMAP info for JSR45 debugging to a
      * file.
      */
-    public boolean isSmapDumped();
+    boolean isSmapDumped();
 
     /**
      * @return {@link TrimSpacesOption#TRUE} to remove template text that
@@ -107,27 +107,17 @@ public interface Options {
      *         replace any sequence of whitespace and new lines within template
      *         text with a single new line.
      */
-    public TrimSpacesOption getTrimSpaces();
-
-    /**
-     * Gets the class-id value that is sent to Internet Explorer when using
-     * &lt;jsp:plugin&gt; tags.
-     * @return Class-id value
-     *
-     * @deprecated Will be removed in Tomcat 10.1.x
-     */
-    @Deprecated
-    public String getIeClassId();
+    TrimSpacesOption getTrimSpaces();
 
     /**
      * @return the work folder
      */
-    public File getScratchDir();
+    File getScratchDir();
 
     /**
      * @return the classpath used to compile generated Servlets
      */
-    public String getClassPath();
+    String getClassPath();
 
     /**
      * Compiler to use.
@@ -140,22 +130,22 @@ public interface Options {
      * Apache Ant documentation for the possible values.
      * @return the compiler name
      */
-    public String getCompiler();
+    String getCompiler();
 
     /**
      * @return the compiler target VM, e.g. 1.8.
      */
-    public String getCompilerTargetVM();
+    String getCompilerTargetVM();
 
     /**
      * @return the compiler source VM, e.g. 1.8.
      */
-    public String getCompilerSourceVM();
+    String getCompilerSourceVM();
 
     /**
      * @return Jasper Java compiler class to use.
      */
-    public String getCompilerClassName();
+    String getCompilerClassName();
 
     /**
      * The cache that maps URIs, resource paths and parsed TLD files for the
@@ -167,12 +157,12 @@ public interface Options {
      * @return the instance of the TldLocationsCache
      *  for the web-application.
      */
-    public TldCache getTldCache();
+    TldCache getTldCache();
 
     /**
      * @return Java platform encoding to generate the JSP page servlet.
      */
-    public String getJavaEncoding();
+    String getJavaEncoding();
 
     /**
      * The boolean flag to tell Ant whether to fork JSP page compilations.
@@ -182,22 +172,22 @@ public interface Options {
      * a <code>javac</code> Apache Ant task).
      * @return <code>true</code> to fork a process during compilation
      */
-    public boolean getFork();
+    boolean getFork();
 
     /**
      * @return JSP configuration information specified in web.xml.
      */
-    public JspConfig getJspConfig();
+    JspConfig getJspConfig();
 
     /**
      * @return <code>true</code> to generate a X-Powered-By response header.
      */
-    public boolean isXpoweredBy();
+    boolean isXpoweredBy();
 
     /**
      * @return a Tag Plugin Manager
      */
-    public TagPluginManager getTagPluginManager();
+    TagPluginManager getTagPluginManager();
 
     /**
      * Indicates whether text strings are to be generated as char arrays.
@@ -205,24 +195,24 @@ public interface Options {
      * @return <code>true</code> if text strings are to be generated as char
      *         arrays, <code>false</code> otherwise
      */
-    public boolean genStringAsCharArray();
+    boolean genStringAsCharArray();
 
     /**
      * @return modification test interval.
      */
-    public int getModificationTestInterval();
+    int getModificationTestInterval();
 
 
     /**
      * @return <code>true</code> if re-compile will occur on a failure.
      */
-    public boolean getRecompileOnFail();
+    boolean getRecompileOnFail();
 
     /**
      * @return <code>true</code> is caching is enabled
      *  (used for precompilation).
      */
-    public boolean isCaching();
+    boolean isCaching();
 
     /**
      * The web-application wide cache for the TagLibraryInfo tag library
@@ -235,7 +225,7 @@ public interface Options {
      *
      * @return the Map(String uri, TagLibraryInfo tld) instance.
      */
-    public Map<String, TagLibraryInfo> getCache();
+    Map<String, TagLibraryInfo> getCache();
 
     /**
      * The maximum number of loaded jsps per web-application. If there are more
@@ -243,25 +233,130 @@ public interface Options {
      * are unloaded.
      * @return The JSP count
      */
-    public int getMaxLoadedJsps();
+    int getMaxLoadedJsps();
 
     /**
      * @return the idle time in seconds after which a JSP is unloaded.
      * If unset or less or equal than 0, no jsps are unloaded.
      */
-    public int getJspIdleTimeout();
+    int getJspIdleTimeout();
 
     /**
      * @return {@code true} if the quote escaping required by section JSP.1.6 of
      *         the JSP specification should be applied to scriplet expression.
      */
-    public boolean getStrictQuoteEscaping();
+    boolean getStrictQuoteEscaping();
 
     /**
      * @return {@code true} if EL expressions used within attributes should have
      *         the quoting rules in JSP.1.6 applied to the expression.
      */
-    public boolean getQuoteAttributeEL();
+    boolean getQuoteAttributeEL();
+
+    /**
+     * @return the name of the variable that will be used in the generated
+     * JSP code for the expression factory
+     */
+    default String getVariableForExpressionFactory() {
+        return "_el_expressionfactory";
+    }
+
+    /**
+     * @return the name of the variable that will be used in the generated
+     * JSP code for the instance manager
+     */
+    default String getVariableForInstanceManager() {
+        return "_jsp_instancemanager";
+    }
+
+    /**
+     * @return {@code true} if tag pooling is disabled with page that uses
+     * extends.
+     */
+    default boolean getPoolTagsWithExtends() {
+        return false;
+    }
+
+    /**
+     * @return {@code true} if the requirement to have the object
+     * used in jsp:getProperty action to be previously "introduced"
+     * to the JSP processor (see JSP.5.3) is enforced.
+     */
+    default boolean getStrictGetProperty() {
+        return true;
+    }
+
+    /**
+     * @return {@code true} if the strict white space rules are
+     * applied.
+     */
+    default boolean getStrictWhitespace() {
+        return true;
+    }
+
+    /**
+     * @return the default base class for generated JSP Servlets
+     */
+    default String getJspServletBase() {
+        return "org.apache.jasper.runtime.HttpJspBase";
+    }
+
+    /**
+     * _jspService is the name of the method that is called by
+     * HttpJspBase.service(). This is where most of the code generated
+     * from JSPs go.
+     * @return the method name
+     */
+    default String getServiceMethodName() {
+        return "_jspService";
+    }
+
+    /**
+     * @return ServletContext attribute for classpath. This is tomcat specific.
+     * Other servlet engines may choose to support this attribute if they
+     * want to have this JSP engine running on them.
+     */
+    default String getServletClasspathAttribute() {
+        return "org.apache.catalina.jsp_classpath";
+    }
+
+    /**
+     * @return The query parameter that causes the JSP engine to just
+     * pregenerated the servlet but not invoke it.
+     */
+    default String getJspPrecompilationQueryParameter() {
+        return "jsp_precompile";
+    }
+
+    /**
+     * @return The default package name for compiled jsp pages.
+     */
+    default String getGeneratedJspPackageName() {
+        return "org.apache.jsp";
+    }
+
+    /**
+     * @return The default package name for tag handlers generated from tag files.
+     */
+    default String getGeneratedTagFilePackageName() {
+        return "org.apache.jsp.tag";
+    }
+
+    /**
+     * @return Prefix to use for generated temporary variable names
+     */
+    default String getTempVariableNamePrefix() {
+        return "_jspx_temp";
+    }
+
+    /**
+     * @return {@code true} if the container instance manager will be used
+     * to create the bean instances
+     */
+    default boolean getUseInstanceManagerForTags() {
+        return false;
+    }
+
 
     /**
      * Should the container include the time the file was generated in the
@@ -270,7 +365,7 @@ public interface Options {
      *
      * @return {@code true} to include the timestamp, otherwise don't include it
      */
-    public default boolean getGeneratedJavaAddTimestamp() {
+    default boolean getGeneratedJavaAddTimestamp() {
         return true;
     }
 }
