@@ -26,11 +26,11 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 
-import javax.servlet.ServletContext;
-import javax.servlet.jsp.tagext.FunctionInfo;
-import javax.servlet.jsp.tagext.TagFileInfo;
-import javax.servlet.jsp.tagext.TagInfo;
-import javax.servlet.jsp.tagext.TagLibraryInfo;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.jsp.tagext.FunctionInfo;
+import jakarta.servlet.jsp.tagext.TagFileInfo;
+import jakarta.servlet.jsp.tagext.TagInfo;
+import jakarta.servlet.jsp.tagext.TagLibraryInfo;
 
 import org.apache.jasper.Constants;
 import org.apache.jasper.JasperException;
@@ -42,8 +42,11 @@ import org.apache.tomcat.util.descriptor.tld.TldResourcePath;
 import org.xml.sax.SAXException;
 
 /**
- * Class responsible for generating an implicit tag library containing tag handlers corresponding to the tag files in
- * "/WEB-INF/tags/" or a subdirectory of it.
+ * Class responsible for generating an implicit tag library containing tag
+ * handlers corresponding to the tag files in "/WEB-INF/tags/" or a
+ * subdirectory of it.
+ *
+ * @author Jan Luehe
  */
 class ImplicitTagLibraryInfo extends TagLibraryInfo {
 
@@ -63,7 +66,11 @@ class ImplicitTagLibraryInfo extends TagLibraryInfo {
     private final List<TagFileInfo> list;
 
 
-    ImplicitTagLibraryInfo(JspCompilationContext ctxt, ParserController pc, PageInfo pi, String prefix, String tagdir,
+    ImplicitTagLibraryInfo(JspCompilationContext ctxt,
+            ParserController pc,
+            PageInfo pi,
+            String prefix,
+            String tagdir,
             ErrorDispatcher err) throws JasperException {
         super(prefix, null);
         this.pc = pc;
@@ -83,7 +90,8 @@ class ImplicitTagLibraryInfo extends TagLibraryInfo {
 
         // Determine the value of the <short-name> subelement of the
         // "imaginary" <taglib> element
-        if (tagdir.equals(WEB_INF_TAGS) || tagdir.equals(WEB_INF_TAGS + "/")) {
+        if (tagdir.equals(WEB_INF_TAGS)
+                || tagdir.equals( WEB_INF_TAGS + "/")) {
             shortname = TAGS_SHORTNAME;
         } else {
             shortname = tagdir.substring(WEB_INF_TAGS.length());
@@ -94,14 +102,18 @@ class ImplicitTagLibraryInfo extends TagLibraryInfo {
         Set<String> dirList = ctxt.getResourcePaths(tagdir);
         if (dirList != null) {
             for (String path : dirList) {
-                if (path.endsWith(TAG_FILE_SUFFIX) || path.endsWith(TAGX_FILE_SUFFIX)) {
+                if (path.endsWith(TAG_FILE_SUFFIX)
+                        || path.endsWith(TAGX_FILE_SUFFIX)) {
                     /*
-                     * Use the filename of the tag file, without the .tag or .tagx extension, respectively, as the
-                     * <name> subelement of the "imaginary" <tag-file> element
+                     * Use the filename of the tag file, without the .tag or
+                     * .tagx extension, respectively, as the <name> subelement
+                     * of the "imaginary" <tag-file> element
                      */
-                    String suffix = path.endsWith(TAG_FILE_SUFFIX) ? TAG_FILE_SUFFIX : TAGX_FILE_SUFFIX;
+                    String suffix = path.endsWith(TAG_FILE_SUFFIX) ?
+                            TAG_FILE_SUFFIX : TAGX_FILE_SUFFIX;
                     String tagName = path.substring(path.lastIndexOf('/') + 1);
-                    tagName = tagName.substring(0, tagName.lastIndexOf(suffix));
+                    tagName = tagName.substring(0,
+                            tagName.lastIndexOf(suffix));
                     tagFileMap.put(tagName, path);
                 } else if (path.endsWith(IMPLICIT_TLD)) {
                     TaglibXml taglibXml;
@@ -109,17 +121,19 @@ class ImplicitTagLibraryInfo extends TagLibraryInfo {
                         URL url = ctxt.getResource(path);
                         TldResourcePath resourcePath = new TldResourcePath(url, path);
                         ServletContext servletContext = ctxt.getServletContext();
-                        boolean validate = Boolean
-                                .parseBoolean(servletContext.getInitParameter(Constants.XML_VALIDATION_TLD_INIT_PARAM));
-                        String blockExternalString =
-                                servletContext.getInitParameter(Constants.XML_BLOCK_EXTERNAL_INIT_PARAM);
+                        boolean validate = Boolean.parseBoolean(
+                                servletContext.getInitParameter(
+                                        Constants.XML_VALIDATION_TLD_INIT_PARAM));
+                        String blockExternalString = servletContext.getInitParameter(
+                                Constants.XML_BLOCK_EXTERNAL_INIT_PARAM);
                         boolean blockExternal;
                         if (blockExternalString == null) {
                             blockExternal = true;
                         } else {
                             blockExternal = Boolean.parseBoolean(blockExternalString);
                         }
-                        TldParser parser = new TldParser(true, validate, new ImplicitTldRuleSet(), blockExternal);
+                        TldParser parser = new TldParser(true, validate,
+                                new ImplicitTldRuleSet(), blockExternal);
                         taglibXml = parser.parse(resourcePath);
                     } catch (IOException | SAXException e) {
                         err.jspError(e);
@@ -148,10 +162,11 @@ class ImplicitTagLibraryInfo extends TagLibraryInfo {
     }
 
     /**
-     * Checks to see if the given tag name maps to a tag file path, and if so, parses the corresponding tag file.
+     * Checks to see if the given tag name maps to a tag file path,
+     * and if so, parses the corresponding tag file.
      *
-     * @return The TagFileInfo corresponding to the given tag name, or null if the given tag name is not implemented as
-     *             a tag file
+     * @return The TagFileInfo corresponding to the given tag name, or null if
+     * the given tag name is not implemented as a tag file
      */
     @Override
     public TagFileInfo getTagFile(String shortName) {
@@ -163,7 +178,7 @@ class ImplicitTagLibraryInfo extends TagLibraryInfo {
                 return null;
             }
 
-            TagInfo tagInfo;
+            TagInfo tagInfo = null;
             try {
                 tagInfo = TagFileProcessor.parseTagFileDirectives(pc, shortName, path, null, this);
             } catch (JasperException je) {
