@@ -14,16 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.jasper.compiler;
 
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Vector;
+import java.util.List;
 
-import javax.servlet.ServletContext;
-import javax.servlet.descriptor.JspConfigDescriptor;
-import javax.servlet.descriptor.JspPropertyGroupDescriptor;
+import jakarta.servlet.ServletContext;
+import jakarta.servlet.descriptor.JspConfigDescriptor;
+import jakarta.servlet.descriptor.JspPropertyGroupDescriptor;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
@@ -41,12 +40,13 @@ public class JspConfig {
     // Logger
     private final Log log = LogFactory.getLog(JspConfig.class); // must not be static
 
-    private Vector<JspPropertyGroup> jspProperties = null;
+    private List<JspPropertyGroup> jspProperties = null;
     private final ServletContext ctxt;
     private volatile boolean initialized = false;
 
     private static final String defaultIsXml = null;    // unspecified
     private String defaultIsELIgnored = null;           // unspecified
+    private String defaultErrorOnELNotFound = "false";
     private static final String defaultIsScriptingInvalid = null;
     private String defaultDeferedSyntaxAllowedAsLiteral = null;
     private static final String defaultTrimDirectiveWhitespaces = null;
@@ -83,7 +83,7 @@ public class JspConfig {
             return;
         }
 
-        jspProperties = new Vector<>();
+        jspProperties = new ArrayList<>();
         Collection<JspPropertyGroupDescriptor> jspPropertyGroups =
                 jspConfig.getJspPropertyGroups();
 
@@ -97,6 +97,7 @@ public class JspConfig {
 
             JspProperty property = new JspProperty(jspPropertyGroup.getIsXml(),
                     jspPropertyGroup.getElIgnored(),
+                    jspPropertyGroup.getErrorOnELNotFound(),
                     jspPropertyGroup.getScriptingInvalid(),
                     jspPropertyGroup.getPageEncoding(),
                     jspPropertyGroup.getIncludePreludes(),
@@ -152,7 +153,7 @@ public class JspConfig {
                 JspPropertyGroup propertyGroup =
                     new JspPropertyGroup(path, extension, property);
 
-                jspProperties.addElement(propertyGroup);
+                jspProperties.add(propertyGroup);
             }
         }
     }
@@ -165,6 +166,7 @@ public class JspConfig {
                     processWebDotXml();
                     defaultJspProperty = new JspProperty(defaultIsXml,
                             defaultIsELIgnored,
+                            defaultErrorOnELNotFound,
                             defaultIsScriptingInvalid,
                             null, null, null,
                             defaultDeferedSyntaxAllowedAsLiteral,
@@ -246,6 +248,7 @@ public class JspConfig {
 
         JspPropertyGroup isXmlMatch = null;
         JspPropertyGroup elIgnoredMatch = null;
+        JspPropertyGroup errorOnELNotFoundMatch = null;
         JspPropertyGroup scriptingInvalidMatch = null;
         JspPropertyGroup pageEncodingMatch = null;
         JspPropertyGroup deferedSyntaxAllowedAsLiteralMatch = null;
@@ -297,6 +300,9 @@ public class JspConfig {
             if (jp.isELIgnored() != null) {
                 elIgnoredMatch = selectProperty(elIgnoredMatch, jpg);
             }
+            if (jp.getErrorOnELNotFound() != null) {
+                errorOnELNotFoundMatch = selectProperty(errorOnELNotFoundMatch, jpg);
+            }
             if (jp.isScriptingInvalid() != null) {
                 scriptingInvalidMatch =
                     selectProperty(scriptingInvalidMatch, jpg);
@@ -328,10 +334,10 @@ public class JspConfig {
 
         String isXml = defaultIsXml;
         String isELIgnored = defaultIsELIgnored;
+        String errorOnELNotFound = defaultErrorOnELNotFound;
         String isScriptingInvalid = defaultIsScriptingInvalid;
         String pageEncoding = null;
-        String isDeferedSyntaxAllowedAsLiteral =
-            defaultDeferedSyntaxAllowedAsLiteral;
+        String isDeferedSyntaxAllowedAsLiteral = defaultDeferedSyntaxAllowedAsLiteral;
         String isTrimDirectiveWhitespaces = defaultTrimDirectiveWhitespaces;
         String defaultContentType = defaultDefaultContentType;
         String buffer = defaultBuffer;
@@ -340,6 +346,9 @@ public class JspConfig {
         if (isXmlMatch != null) {
             isXml = isXmlMatch.getJspProperty().isXml();
         }
+        if (errorOnELNotFoundMatch != null) {
+            errorOnELNotFound = errorOnELNotFoundMatch.getJspProperty().getErrorOnELNotFound();
+        }
         if (elIgnoredMatch != null) {
             isELIgnored = elIgnoredMatch.getJspProperty().isELIgnored();
         }
@@ -370,7 +379,7 @@ public class JspConfig {
                 errorOnUndeclaredNamespaceMatch.getJspProperty().isErrorOnUndeclaredNamespace();
         }
 
-        return new JspProperty(isXml, isELIgnored, isScriptingInvalid,
+        return new JspProperty(isXml, isELIgnored, errorOnELNotFound, isScriptingInvalid,
                 pageEncoding, includePreludes, includeCodas,
                 isDeferedSyntaxAllowedAsLiteral, isTrimDirectiveWhitespaces,
                 defaultContentType, buffer, errorOnUndeclaredNamespace);
@@ -450,6 +459,7 @@ public class JspConfig {
 
         private final String isXml;
         private final String elIgnored;
+        private final String errorOnELNotFound;
         private final String scriptingInvalid;
         private final String pageEncoding;
         private final Collection<String> includePrelude;
@@ -460,7 +470,7 @@ public class JspConfig {
         private final String buffer;
         private final String errorOnUndeclaredNamespace;
 
-        public JspProperty(String isXml, String elIgnored,
+        public JspProperty(String isXml, String elIgnored, String errorOnELNotFound,
                 String scriptingInvalid, String pageEncoding,
                 Collection<String> includePrelude, Collection<String> includeCoda,
                 String deferedSyntaxAllowedAsLiteral,
@@ -471,6 +481,7 @@ public class JspConfig {
 
             this.isXml = isXml;
             this.elIgnored = elIgnored;
+            this.errorOnELNotFound = errorOnELNotFound;
             this.scriptingInvalid = scriptingInvalid;
             this.pageEncoding = pageEncoding;
             this.includePrelude = includePrelude;
@@ -490,6 +501,10 @@ public class JspConfig {
             return elIgnored;
         }
 
+        public String getErrorOnELNotFound() {
+            return errorOnELNotFound;
+        }
+
         public String isScriptingInvalid() {
             return scriptingInvalid;
         }
