@@ -23,13 +23,13 @@ public final class InstanceManagerBindings {
 
     private static final Map<ClassLoader, InstanceManager> bindings = new ConcurrentHashMap<>();
 
-    public static final void bind(ClassLoader classLoader, InstanceManager instanceManager) {
+    public static void bind(ClassLoader classLoader, InstanceManager instanceManager) {
         bindings.put(classLoader, instanceManager);
     }
-    public static final void unbind(ClassLoader classLoader) {
+    public static void unbind(ClassLoader classLoader) {
         bindings.remove(classLoader);
     }
-    public static final InstanceManager get(ClassLoader classLoader) {
+    public static InstanceManager get(ClassLoader classLoader) {
         return bindings.get(classLoader);
     }
 }
