@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      https://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -74,9 +74,9 @@ public class PoolingConnection extends DelegatingConnection<Connection>
     }
 
     /** Pool of {@link PreparedStatement}s. and {@link CallableStatement}s */
-    private KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> stmtPool;
+    private KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> pStmtPool;
 
-    private volatile boolean clearStatementPoolOnReturn;
+    private boolean clearStatementPoolOnReturn;
 
     /**
      * Constructs a new instance.
@@ -109,9 +109,9 @@ public class PoolingConnection extends DelegatingConnection<Connection>
     @Override
     public synchronized void close() throws SQLException {
         try {
-            if (null != stmtPool) {
-                final KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> oldPool = stmtPool;
-                stmtPool = null;
+            if (null != pStmtPool) {
+                final KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> oldPool = pStmtPool;
+                pStmtPool = null;
                 try {
                     oldPool.close();
                 } catch (final RuntimeException e) {
@@ -122,10 +122,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
             }
         } finally {
             try {
-                final Connection delegateInternal = getDelegateInternal();
-                if (delegateInternal != null) {
-                    delegateInternal.close();
-                }
+                getDelegateInternal().close();
             } finally {
                 setClosedInternal(true);
             }
@@ -140,9 +137,9 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      * @since 2.8.0
      */
     public void connectionReturnedToPool() throws SQLException {
-        if (stmtPool != null && clearStatementPoolOnReturn) {
+        if (pStmtPool != null && clearStatementPoolOnReturn) {
             try {
-                stmtPool.clear();
+                pStmtPool.clear();
             } catch (final Exception e) {
                 throw new SQLException("Error clearing statement pool", e);
             }
@@ -168,7 +165,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *            the SQL string used to define the statement
      * @param autoGeneratedKeys
      *            A flag indicating whether auto-generated keys should be returned; one of
-     *            {@link Statement#RETURN_GENERATED_KEYS} or {@link Statement#NO_GENERATED_KEYS}.
+     *            {@code Statement.RETURN_GENERATED_KEYS} or {@code Statement.NO_GENERATED_KEYS}.
      *
      * @return the PStmtKey created for the given arguments.
      */
@@ -341,7 +338,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      * @since 2.8.0
      */
     public KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> getStatementPool() {
-        return stmtPool;
+        return pStmtPool;
     }
 
     /**
@@ -361,11 +358,11 @@ public class PoolingConnection extends DelegatingConnection<Connection>
         if (key.getStmtType() == StatementType.PREPARED_STATEMENT) {
             final PreparedStatement statement = (PreparedStatement) key.createStatement(getDelegate());
             @SuppressWarnings({"rawtypes", "unchecked" }) // Unable to find way to avoid this
-            final PoolablePreparedStatement pps = new PoolablePreparedStatement(statement, key, stmtPool, this);
+            final PoolablePreparedStatement pps = new PoolablePreparedStatement(statement, key, pStmtPool, this);
             return new DefaultPooledObject<>(pps);
         }
         final CallableStatement statement = (CallableStatement) key.createStatement(getDelegate());
-        final PoolableCallableStatement pcs = new PoolableCallableStatement(statement, key, stmtPool, this);
+        final PoolableCallableStatement pcs = new PoolableCallableStatement(statement, key, pStmtPool, this);
         return new DefaultPooledObject<>(pcs);
     }
 
@@ -373,6 +370,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      * Normalizes the given SQL statement, producing a canonical form that is semantically equivalent to the original.
      *
      * @param sql The statement to be normalized.
+     *
      * @return The canonical form of the supplied SQL statement.
      */
     protected String normalizeSQL(final String sql) {
@@ -474,11 +472,11 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *             Wraps an underlying exception.
      */
     private PreparedStatement prepareStatement(final PStmtKey key) throws SQLException {
-        if (null == stmtPool) {
+        if (null == pStmtPool) {
             throw new SQLException("Statement pool is null - closed or invalid PoolingConnection.");
         }
         try {
-            return stmtPool.borrowObject(key);
+            return pStmtPool.borrowObject(key);
         } catch (final NoSuchElementException e) {
             throw new SQLException("MaxOpenPreparedStatements limit reached", e);
         } catch (final RuntimeException e) {
@@ -509,7 +507,7 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *            the SQL string used to define the PreparedStatement
      * @param autoGeneratedKeys
      *            A flag indicating whether auto-generated keys should be returned; one of
-     *            {@link Statement#RETURN_GENERATED_KEYS} or {@link Statement#NO_GENERATED_KEYS}.
+     *            {@code Statement.RETURN_GENERATED_KEYS} or {@code Statement.NO_GENERATED_KEYS}.
      * @return a {@link PoolablePreparedStatement}
      * @throws SQLException
      *             Wraps an underlying exception.
@@ -610,19 +608,19 @@ public class PoolingConnection extends DelegatingConnection<Connection>
      *            the prepared statement pool.
      */
     public void setStatementPool(final KeyedObjectPool<PStmtKey, DelegatingPreparedStatement> pool) {
-        stmtPool = pool;
+        pStmtPool = pool;
     }
 
     @Override
     public synchronized String toString() {
-        if (stmtPool instanceof GenericKeyedObjectPool) {
+        if (pStmtPool instanceof GenericKeyedObjectPool) {
             // DBCP-596 PoolingConnection.toString() causes StackOverflowError
-            final GenericKeyedObjectPool<?, ?> gkop = (GenericKeyedObjectPool<?, ?>) stmtPool;
+            final GenericKeyedObjectPool<?, ?> gkop = (GenericKeyedObjectPool<?, ?>) pStmtPool;
             if (gkop.getFactory() == this) {
-                return "PoolingConnection: " + stmtPool.getClass() + "@" + System.identityHashCode(stmtPool);
+                return "PoolingConnection: " + pStmtPool.getClass() + "@" + System.identityHashCode(pStmtPool);
             }
         }
-        return "PoolingConnection: " + Objects.toString(stmtPool);
+        return "PoolingConnection: " + Objects.toString(pStmtPool);
     }
 
     /**
