@@ -91,7 +91,7 @@ public class Rfc6265CookieProcessor extends CookieProcessorBase {
                 }
                 ByteChunk bc = cookieValue.getByteChunk();
 
-                Cookie.parseCookie(bc.getBytes(), bc.getOffset(), bc.getLength(), serverCookies);
+                Cookie.parseCookie(bc.getBytes(), bc.getStart(), bc.getLength(), serverCookies);
             }
 
             // search from the next position
