@@ -29,8 +29,8 @@ import jakarta.websocket.DeploymentException;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Extracts path parameters from URIs used to create web socket connections
- * using the URI template defined for the associated Endpoint.
+ * Extracts path parameters from URIs used to create web socket connections using the URI template defined for the
+ * associated Endpoint.
  */
 public class UriTemplate {
 
@@ -45,8 +45,7 @@ public class UriTemplate {
 
         if (path == null || path.length() == 0 || !path.startsWith("/") || path.contains("/../") ||
                 path.contains("/./") || path.contains("//")) {
-            throw new DeploymentException(
-                    sm.getString("uriTemplate.invalidPath", path));
+            throw new DeploymentException(sm.getString("uriTemplate.invalidPath", path));
         }
 
         StringBuilder normalized = new StringBuilder(path.length());
@@ -69,8 +68,7 @@ public class UriTemplate {
                 } else {
                     // As per EG discussion, all other empty segments are
                     // invalid
-                    throw new DeploymentException(sm.getString(
-                            "uriTemplate.emptySegment", path));
+                    throw new DeploymentException(sm.getString("uriTemplate.emptySegment", path));
                 }
             }
             normalized.append('/');
@@ -82,13 +80,11 @@ public class UriTemplate {
                 normalized.append(paramCount++);
                 normalized.append('}');
                 if (!paramNames.add(segment)) {
-                    throw new DeploymentException(sm.getString(
-                            "uriTemplate.duplicateParameter", segment));
+                    throw new DeploymentException(sm.getString("uriTemplate.duplicateParameter", segment));
                 }
             } else {
                 if (segment.contains("{") || segment.contains("}")) {
-                    throw new DeploymentException(sm.getString(
-                            "uriTemplate.invalidSegment", segment, path));
+                    throw new DeploymentException(sm.getString("uriTemplate.invalidSegment", segment, path));
                 }
                 normalized.append(segment);
             }
@@ -101,9 +97,9 @@ public class UriTemplate {
     }
 
 
-    public Map<String,String> match(UriTemplate candidate) {
+    public Map<String, String> match(UriTemplate candidate) {
 
-        Map<String,String> result = new HashMap<>();
+        Map<String, String> result = new HashMap<>();
 
         // Should not happen but for safety
         if (candidate.getSegmentCount() != getSegmentCount()) {
@@ -117,15 +113,13 @@ public class UriTemplate {
 
             if (targetSegment.getParameterIndex() == -1) {
                 // Not a parameter - values must match
-                if (!targetSegment.getValue().equals(
-                        candidateSegment.getValue())) {
+                if (!targetSegment.getValue().equals(candidateSegment.getValue())) {
                     // Not a match. Stop here
                     return null;
                 }
             } else {
                 // Parameter
-                result.put(targetSegment.getValue(),
-                        candidateSegment.getValue());
+                result.put(targetSegment.getValue(), candidateSegment.getValue());
             }
         }
 
