@@ -18,7 +18,7 @@ package org.apache.catalina.valves;
 
 import java.io.IOException;
 
-import javax.servlet.ServletException;
+import jakarta.servlet.ServletException;
 
 import org.junit.Assert;
 import org.junit.Test;
@@ -125,7 +125,7 @@ public class TestRequestFilterValve {
                 if (usePeerAddress) {
                     request.setRemoteAddr(ADDR_OTHER);
                     request.getCoyoteRequest().peerAddr().setString(property);
-                    valve.setUsePeerAddress(true);
+                    ((RemoteAddrValve) valve).setUsePeerAddress(true);
                     msg.append(" peer='" + property + "'");
                 } else {
                     request.setRemoteAddr(property);
@@ -141,7 +141,7 @@ public class TestRequestFilterValve {
                 if (usePeerAddress) {
                     request.setRemoteAddr(ADDR_OTHER);
                     request.getCoyoteRequest().peerAddr().setString(property);
-                    valve.setUsePeerAddress(true);
+                    ((RemoteCIDRValve) valve).setUsePeerAddress(true);
                     msg.append(" peer='" + property + "'");
                 } else {
                     request.setRemoteAddr(property);
@@ -170,11 +170,11 @@ public class TestRequestFilterValve {
         }
         if (addConnectorPort) {
             if (valve instanceof RemoteAddrValve) {
-                valve.setAddConnectorPort(true);
+                ((RemoteAddrValve) valve).setAddConnectorPort(true);
             } else if (valve instanceof RemoteHostValve) {
-                valve.setAddConnectorPort(true);
+                ((RemoteHostValve) valve).setAddConnectorPort(true);
             } else if (valve instanceof RemoteCIDRValve) {
-                valve.setAddConnectorPort(true);
+                ((RemoteCIDRValve) valve).setAddConnectorPort(true);
             } else {
                 Assert.fail("Can only set 'addConnectorPort' for RemoteAddrValve, RemoteHostValve and RemoteCIDRValve");
             }
