@@ -20,14 +20,14 @@ package org.apache.coyote.http2;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 
-import javax.servlet.AsyncContext;
-import javax.servlet.AsyncEvent;
-import javax.servlet.AsyncListener;
-import javax.servlet.ReadListener;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServlet;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
+import jakarta.servlet.AsyncContext;
+import jakarta.servlet.AsyncEvent;
+import jakarta.servlet.AsyncListener;
+import jakarta.servlet.ReadListener;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.http.HttpServlet;
+import jakarta.servlet.http.HttpServletRequest;
+import jakarta.servlet.http.HttpServletResponse;
 
 import org.junit.Assert;
 import org.junit.Before;
@@ -47,27 +47,10 @@ public class TestAsyncReadListener extends Http2TestBase {
         asyncServlet = new AsyncServlet();
     }
 
-
     @Test
-    public void testEmptyWindowDefaultReadTimeout() throws Exception {
-        doTestEmptyWindowMaximumTimeout(false);
-    }
-
-
-    @Test
-    public void testEmptyWindowMaximumReadTimeout() throws Exception {
-        doTestEmptyWindowMaximumTimeout(true);
-    }
-
-
-    public void doTestEmptyWindowMaximumTimeout(boolean useMaxReadTimeout) throws Exception {
+    public void testEmptyWindow() throws Exception {
         http2Connect();
 
-        if (useMaxReadTimeout) {
-            http2Protocol.setStreamReadTimeout(Integer.MAX_VALUE);
-            http2Protocol.setReadTimeout(Integer.MAX_VALUE);
-        }
-
         byte[] headersFrameHeader = new byte[9];
         ByteBuffer headersPayload = ByteBuffer.allocate(128);
         byte[] dataFrameHeader = new byte[9];
@@ -77,8 +60,7 @@ public class TestAsyncReadListener extends Http2TestBase {
 
 
         buildPostRequest(headersFrameHeader, headersPayload, false, null, -1, "/async", dataFrameHeader, dataPayload,
-            null, true, 3);
-        buildTrailerHeaders(trailerFrameHeader, trailerPayload, 3);
+            null, trailerFrameHeader, trailerPayload, 3);
 
         synchronized (asyncServlet) {
             // Write the headers
